/*
 * This file contains all localizable skin settings such as 
 *   font, layout, and geometry
 */
window { 
  font: 3mm tahoma,arial,helvetica,sans-serif;
}
#extensionsManager {
 width: 55em !important;
}
#advancedScripts {
  min-width: 30em !important;
}
